@@ -24,7 +24,7 @@ read.GenBank <- function(access.nb, seq.names = access.nb)
 {
     obj <- lapply(as.list(access.nb), get.dna)
     names(obj) <- seq.names
-    return(obj)
+    obj
 }
 
 get.dna <- function(access.nb)
@@ -36,5 +36,5 @@ get.dna <- function(access.nb)
     LA <- which(tmp == "//") - 1
     tmp <- unlist(strsplit(tmp[FI:LA], NULL))
     tmp <- tmp[grep("[acgt]", tmp)]
-    return(tmp)
+    tmp
 }
